<?php

namespace EventPortal\Domain\Component;

use Illuminate\Support\Arr;
use Illuminate\Support\Str;

abstract class Input extends Component
{
    /** @var null|string|array */
    public $value;

    /** @var null|string */
    public $placeholder;

    /** @var bool */
    public $clearable = false;

    /** @var bool */
    public $required = false;

    /** @var null|array */
    public $validation;

    /** @var null|array */
    public $createValidation;

    /** @var null|array */
    public $updateValidation;

    public function hasOptions(): bool
    {
        return false;
    }

    /**
     * @param string|array $value
     * @return $this
     */
    public function value($value): Input
    {
        $this->value = $value;

        return $this;
    }

    /**
     * @param null|string|array $rules
     */
    public function validation($rules): self
    {
        if ($rules === null) {
            return $this;
        }

        $rules = $this->parseRules($rules);

        $this->validation = $rules;

        if (in_array('required', $rules, true)) {
            $this->required = true;
        }

        return $this;
    }

    /**
     * @param null|string|array $rules
     */
    public function createValidation($rules): self
    {
        if ($rules === null) {
            return $this;
        }

        $this->createValidation = $this->parseRules($rules);

        return $this;
    }

    /**
     * @param null|string|array $rules
     */
    public function updateValidation($rules): self
    {
        if ($rules === null) {
            return $this;
        }

        $this->updateValidation = $this->parseRules($rules);

        return $this;
    }

    public function placeholder(?string $placeholder): self
    {
        $this->placeholder = $placeholder;

        return $this;
    }

    public function clearable(?bool $clearable): self
    {
        $this->clearable = $clearable ?? false;

        return $this;
    }

    /**
     * Returns the component as an array.
     */
    public function toArray(): array
    {
        $data = array_merge(parent::toArray(), [
            'clearable' => $this->clearable,
            'required' => $this->required,
        ]);

        if ($this->placeholder !== null) {
            $data['placeholder'] = $this->placeholder;
        }

        if ($this->value !== null) {
            $data['value'] = $this->value;
        }

        if (Arr::get($data, 'value') === null) {
            unset($data['value']);
        }

        return $data;
    }

    /**
     * @param string|array $rules
     */
    private function parseRules($rules): array
    {
        if (is_string($rules)) {
            $rules = Str::of($rules)->explode('|')->toArray();
        }

        return Arr::wrap($rules);
    }
}
