<?php

namespace EventPortal\Domain\Event\Models;

use EventPortal\Concerns\HasFields as HasFieldsConcern;
use EventPortal\Contracts\HasFields;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Table\GroupedActions;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Database\Eloquent\Model;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableContract;

class Event extends Model implements AuditableContract, HasFields
{
    use Auditable, HasFieldsConcern;

    /** @var array<string> */
    protected $guarded = [];

    public function tableActions(): GroupedActions
    {
        $event = $this;

        return GroupedActions::make('Manage event')
            ->add(static function () use ($event): Button {
                return Button::make('View')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.show', ['event' => $event->id]);
            })
            ->add(static function () use ($event): Button {
                return Button::make('Edit')
                    ->method(InertiaMethod::VISIT())
                    ->route('admin.event.edit', ['event' => $event->id]);
            });
    }
}
