<?php

namespace EventPortal\Domain\Field\Actions;

use EventPortal\Contracts\HasFields;
use EventPortal\Domain\Field\Enums\FieldType;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Response\Models\Response;
use Illuminate\Support\Arr;
use Illuminate\Support\Str;

class InitialiseFields
{
    public function execute(array $sections, HasFields $model): HasFields
    {
        collect($sections)
            ->each(function ($rawSection) use ($model): void {
                $section = $this->createSection($rawSection, $model);

                collect(Arr::get($rawSection, 'children'))
                    ->each(function ($child) use ($section, $model): void {
                        $this->createField($section, $model, $child);
                    });
            });

        return $model;
    }

    private function createSection(array $section, HasFields $model): Field
    {
        $label = Arr::get($section, 'label');

        return Field::create([
            'model_id' => $model->id,
            'model_type' => get_class($model),
            'type' => FieldType::Section()->getName(),
            'label' => $label,
        ]);
    }

    /**
     * Creates fields.
     */
    private function createField(Field $section, HasFields $model, array $child): Field
    {
        $label = Arr::get($child, 'label');

        $field = Field::create([
            'model_id' => $model->id,
            'model_type' => get_class($model),
            'section_id' => $section->id,
            'type' => Arr::get($child, 'component'),
            'label' => $label,
            'name' => Arr::get($child, 'name', Str::slug($label, '_')),
        ]);

        if (Arr::get($child, 'options') !== null) {
            $field->data->set('options', Arr::get($child, 'options'));
        }

        if (Arr::get($child, 'validation') !== null) {
            $field->data->set('validation', Arr::get($child, 'validation'));
        }

        if (Arr::get($child, 'updateValidation') !== null) {
            $field->data->set('updateValidation', Arr::get($child, 'updateValidation'));
        }

        if (Arr::get($child, 'createValidation') !== null) {
            $field->data->set('createValidation', Arr::get($child, 'createValidation'));
        }

        if (Arr::get($child, 'placeholder') !== null) {
            $field->data->set('placeholder', Arr::get($child, 'placeholder'));
        }

        if (Arr::get($child, 'value') !== null) {
            Response::create([
                'field_id' => $field->id,
                'value' => Arr::get($child, 'value'),
            ]);
        }

        $field->save();

        return $field;
    }
}
