<?php

namespace EventPortal\Domain\Field\Builders;

use EventPortal\Contracts\HasFields;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Facades\DB;

class FieldBuilder extends Builder
{
    public function hasResponseOf(string $value): self
    {
        $this
            ->whereHas('response', static function ($query) use ($value) {
                return $query
                    ->where(function ($query) use ($value) {
                        return $query
                            ->where('data->value->value', '=', $value)
                            ->orWhere(DB::raw("json_extract(data, '$.value[*].value')"), 'LIKE', '%' .$value. '%');
                    });
            });

        return $this;
    }

    public function hasResponseLike(string $value): self
    {
        $this
            ->whereHas('response', static function ($query) use ($value) {
                return $query
                    ->where(DB::raw('lower(data->"$.value")'), 'LIKE', '%' . strtolower($value). '%');
            });

        return $this;
    }

    public function forModel(HasFields $model): self
    {
        $this
            ->where('model_id', $model->id)
            ->where('model_type', get_class($model));

        return $this;
    }

    public function forModelType(HasFields $model): self
    {
        $this->where('model_type', get_class($model));

        return $this;
    }

    public function onlySections(): self
    {
        $this->whereNull('section_id');

        return $this;
    }

    public function onlyChildren(): self
    {
        $this->whereNotNull('section_id');

        return $this;
    }
}
