<?php

namespace EventPortal\Tests\Unit\Models;

use EventPortal\Domain\Response\Models\Response;
use EventPortal\Tests\Support\Traits\IsAudited;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class ResponseTest extends TestCase
{
    use DatabaseMigrations, isAudited;

    /** @test **/
    public function can_get_value()
    {
        $response = factory(Response::class)->create();
        $response->data->set('value', 'Hello World!');
        $response->save();

        $this->assertEquals('Hello World!', $response->value);
    }

    /** @test **/
    public function can_set_value()
    {
        $response = factory(Response::class)->create();
        $response->value = 'Hello World!';
        $response->save();

        $this->assertEquals('Hello World!', $response->value);
    }

    /** @test **/
    public function responses_are_audited()
    {
        $old = [
            'data' => '{"value": {"label": "Old Label", "value": "old-value"}}',
        ];

        $new = [
            'data' => '{"value": {"label": "New Label", "value": "new-value"}}',
        ];

        $this->assertAudited(Response::class, $old, $new);
    }
}
